%  [phi,L,a,b] = CALCULA_PHI(Z,entorno) Calcula Phi_m para cada Z teniendo en cuenta el entorno
%    opcionalmente devuelve otros parmetros intermedios que pueden ser tiles, como L
%
%1. Extremadamente inestable
%2. Moderadamente inestable
%3. Ligeramente inestable
%4. Neutro
%5. Ligeramente estable
%6. Moderadamente estable
function [phi,L,a,b] = calcula_phi(Z,entorno)

    criterio_estabilidad = entorno.criterio_estabilidad;
    if criterio_estabilidad < 1 | criterio_estabilidad > 6
		error('el criterio de estabilidad debe de estar comprendido entre 1 y 6')
	end

    Zo = entorno.Z0;
    if Zo <= 0
        error('Zo tiene que ser mayor que 0')
    end
    
    criterio_estabilidad = round(criterio_estabilidad); %redondeamos por si acaso

    %calculo de phi, "a" y "b" y "L" en funcion de la estabilidad
    switch criterio_estabilidad
    case 1 %Extremadamente inestable
      a= -0.0875;
      b= -0.1029;
      L= 1/(a*(Zo^b));
      theta= (1-((16*Z)/L)).^0.25;
      phi= log((((theta.^2)+1)/2).*(((1+theta)/2).^2))-(2*atan(theta))+(pi/2);
    case 2 %Moderadamente inestable
      a= -0.03849;
      b= -0.1714;
      L=1/(a*(Zo^b));
      theta=(1-((16*Z)./L)).^0.25;
      phi=log((((theta.^2)+1)/2).*(((1+theta)/2).^2))-(2*atan(theta))+(pi/2);
    case 3 %Ligeramente inestable
      a= -0.00807;
      b= -0.3049;
      L=1/(a*(Zo^b)); 
      theta=(1-((16*Z)./L)).^0.25;
      phi=log((((theta.^2)+1)/2).*(((1+theta)/2).^2))-(2*atan(theta))+(pi/2);
    case 4 %Neutro
      a=0;
      b=0;
      L = inf;
      phi= zeros(size(Z));
    case 5 %Ligeramente estable
      a=0.00807;
      b=-0.3049;
      L=1/(a*(Zo^b));
      phi=-(5*Z)./L;
    case 6 %moderadamente estable
      a=0.03849;
      b=-0.1714;
      L=1/(a*(Zo^b));
      phi=-(5*Z)./L;
    end
return
