% v_fricc = CALCULA_V_FRICC(estacion,entorno)  Calcula la velocidad de
%       friccin ptima para las medidas tomadas verticalmente con la estacion,
%       segn el criterio de estabilidad, con valor entre 1 (inestable) y 6 (estable)
function v_fricc = calcula_v_fricc(estacion,entorno)


    k = entorno.k; % constante de Karman
    Z0 = entorno.Z0;
    Ze = estacion.Ze;
    V0 = estacion.V0;
    Phi_m = calcula_phi(Ze,entorno); %calculamos Phi para cada Ze
    n = length(Ze);
    
    % Calculamos las A_i (Ec. 5.56)
    A = zeros(1,n);
    for i = 1:n
        A(i) = (log(Ze(i)/Z0) - Phi_m(i))/k;
    end

    %calculamos la velocidad de friccin ptima (Ec. 5.59)
    numerador = [0,0];
    denominador = 0;
    for i = 1:n
        numerador = numerador + A(i)*V0(i,:);
        denominador = denominador + A(i)^2;
    end
    v_fricc = numerador / denominador;


return
