% CALCULA_VIENTO_GEOSTROFICO 
%
%   Vg = calcula_viento_geostrofico(v_fricc,entorno) calcula el viento geostrfico a partir
%       de la velocidad de friccin y de las variables de entorno pasadas por parmetro. 
%       Ecuaciones 5.61 y 5.62
%
function Vg = calcula_viento_geostrofico(v_fricc,entorno)
    %valores A y B aceptables para condiciones neutras de estabilidad atmosfrica
    A = 1.8; 
    B = 4.5;

    k = entorno.k;
    f = entorno.f;
    Z0 = entorno.Z0;
    v = norm(v_fricc);

    modulo_Vg = v*sqrt((log(v/(f*Z0)) -A)^2 + B^2)/k;
    phi_Vg = atan2(log(v/(f*Z0)) -A,B);
    Vg = [modulo_Vg*cos(phi_Vg),modulo_Vg*sin(phi_Vg)];

return
