%
% perfil = PERFIL_VERTICAL(estacion,entorno) calcula el perfil vertical del viento
%   para los valores definidos en el vector Z, teniendo en cuenta los valores medidos
%   por la estacin y las condiciones del entorno. Perfil es una estructura que contiene
%   los valores [u,v] del viento para cada Z, as como de otra informacin interesante
%
function perfil = perfil_vertical(estacion,entorno)

    Zmax = 10000;

    Z = 0:0.5:Zmax;

    gamma = 0.2; % comprendido entre 0.15 y 0.45

    f = entorno.f;
    k = entorno.k; %constante de karman
    Z0 = entorno.Z0;

    v_fricc = calcula_v_fricc(estacion,entorno);

    Zpbl = gamma*norm(v_fricc)/f; %altitud capa limite planetaria

    [phi_m,L] = calcula_phi(Z,entorno);

    Hm = 0.4*sqrt(norm(v_fricc)*L/f); % altitud de capa de mezcla
    
    Zsl = Hm / 10; 

    %viento Geostrfico
    Vg = calcula_viento_geostrofico(v_fricc,entorno);
    %velocidad del viento en Zsl
    V_Zsl = v_fricc*(log(Zsl/Z0) - calcula_phi(Zsl,entorno))/k;
    
    %almacenamos todos los valores importantes en perfil
    perfil.v_fricc = v_fricc;
    perfil.Vg = Vg;
    perfil.V_Zsl = V_Zsl;
    perfil.Z0 = Z0;
    perfil.Zpbl = Zpbl;
    perfil.Zsl = Zsl;
    perfil.Hm = Hm;
    perfil.entorno = entorno

    %calculamos la velocidad para cada Z del perfil
    for i = 1:length(Z)
    	V(i,:) = punto_perfil(perfil,Z(i));
    end

    perfil.V = V;
    perfil.Z = Z;

return
