% PUNTO_PERFIL Velocidad del viento a una altura
%
% v = PUNTO_PERFIL(perfil,z) evalua el valor de la la velocidad del viento del 
%     perfil en el z especificado. Tiene en cuenta las distintas capas de 
%     estratificacin atmosfrica.
function v = punto_perfil(perfil,z)
    v_fricc = perfil.v_fricc;
    Vg = perfil.Vg;
    V_Zsl = perfil.V_Zsl;
    Z0 = perfil.Z0;
    Zpbl = perfil.Zpbl;
    Zsl = perfil.Zsl;
    Hm = perfil.Hm;
    k = perfil.entorno.k;

    % la velocidad depende de la capa de estratificacin de la atmsfera
    if z <= Z0
        v = [0,0];
    elseif z <= Zsl
    	phi_m = calcula_phi(z,perfil.entorno); %Ec. 5.53
        v = v_fricc*(log(z/Z0) - phi_m)/k;
    elseif z <= Zpbl 
        p = rho(z,Zsl,Zpbl); %Ec. 5.64
        v = p*V_Zsl + (1-p)*Vg;
    else
        v = Vg;
    end

return
